@@ -26,6 +26,94 @@ class EssbasicClient(AbstractClient):
     _service = 'essbasic'
 
 
+    def ChannelCancelMultiFlowSignQRCode(self, request):
+        """此接口（ChannelCancelMultiFlowSignQRCode）用于取消一码多扫二维码。该接口对传入的二维码ID，若还在有效期内，可以提前失效。
+
+        :param request: Request instance for ChannelCancelMultiFlowSignQRCode.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCancelMultiFlowSignQRCodeRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCancelMultiFlowSignQRCodeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCancelMultiFlowSignQRCode", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelCancelMultiFlowSignQRCodeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ChannelCreateFlowByFiles(self, request):
+        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建流程。此接口不可直接使用，需要运营申请
+
+        :param request: Request instance for ChannelCreateFlowByFiles.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreateFlowByFiles", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelCreateFlowByFilesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ChannelCreateMultiFlowSignQRCode(self, request):
+        """此接口（ChannelCreateMultiFlowSignQRCode）用于创建一码多扫流程签署二维码。
+        适用的模版仅限于B2C（1、无序签署，2、顺序签署时B静默签署，3、顺序签署时B非首位签署）、单C的模版，且模版中发起方没有填写控件。
+
+        :param request: Request instance for ChannelCreateMultiFlowSignQRCode.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateMultiFlowSignQRCodeRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateMultiFlowSignQRCodeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreateMultiFlowSignQRCode", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelCreateMultiFlowSignQRCodeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateConsoleLoginUrl(self, request):
         """此接口（CreateConsoleLoginUrl）用于创建电子签控制台登录链接。若企业未激活，调用同步企业信息、同步经办人信息
 
@@ -36,7 +124,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateConsoleLoginUrl", params)
+            headers = request.headers
+            body = self.call("CreateConsoleLoginUrl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateConsoleLoginUrlResponse()
@@ -64,7 +153,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateFlowsByTemplates", params)
+            headers = request.headers
+            body = self.call("CreateFlowsByTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateFlowsByTemplatesResponse()
@@ -82,6 +172,35 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateSealByImage(self, request):
+        """渠道通过图片为子客代创建印章，图片最大5m；此接口不可直接使用，需要运营申请
+
+        :param request: Request instance for CreateSealByImage.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSealByImageRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.CreateSealByImageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSealByImage", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateSealByImageResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSignUrls(self, request):
         """创建参与者签署短链
 
@@ -92,7 +211,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSignUrls", params)
+            headers = request.headers
+            body = self.call("CreateSignUrls", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSignUrlsResponse()
@@ -120,7 +240,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFlowDetailInfo", params)
+            headers = request.headers
+            body = self.call("DescribeFlowDetailInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFlowDetailInfoResponse()
@@ -139,7 +260,8 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeResourceUrlsByFlows(self, request):
-        """根据流程信息批量获取资源下载链接
+        """根据流程信息批量获取资源下载链接，可直接下载
+        限制：只能下载合作企业授权过的、单方签署的流程文件（若合作企业与渠道是同一企业，可以下载所有流程文件）
 
         :param request: Request instance for DescribeResourceUrlsByFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeResourceUrlsByFlowsRequest`
@@ -148,7 +270,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceUrlsByFlows", params)
+            headers = request.headers
+            body = self.call("DescribeResourceUrlsByFlows", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceUrlsByFlowsResponse()
@@ -176,7 +299,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTemplatesResponse()
@@ -205,7 +329,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUsage", params)
+            headers = request.headers
+            body = self.call("DescribeUsage", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUsageResponse()
@@ -224,7 +349,7 @@ class EssbasicClient(AbstractClient):
 
 
     def GetDownloadFlowUrl(self, request):
-        """此接口（GetDownloadFlowUrl）用于创建电子签批量下载确认页面链接，支持客户合同（流程）按照自定义文件夹形式 分类下载。
+        """此接口（GetDownloadFlowUrl）用于创建电子签批量下载地址，让合作企业进入控制台直接下载，支持客户合同（流程）按照自定义文件夹形式 分类下载。
         当前接口限制最多合同（流程）50个.
 
         :param request: Request instance for GetDownloadFlowUrl.
@@ -234,7 +359,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetDownloadFlowUrl", params)
+            headers = request.headers
+            body = self.call("GetDownloadFlowUrl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetDownloadFlowUrlResponse()
@@ -266,7 +392,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("OperateChannelTemplate", params)
+            headers = request.headers
+            body = self.call("OperateChannelTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.OperateChannelTemplateResponse()
@@ -287,7 +414,7 @@ class EssbasicClient(AbstractClient):
     def PrepareFlows(self, request):
         """该接口 (PrepareFlows) 用于创建待发起文件
         用户通过该接口进入流程发起的确认页面，进行发起信息二次确认， 如果确认则进行正常发起。
-        目前该接口只支持B2C。
+        目前该接口只支持B2C，不建议使用。
 
         :param request: Request instance for PrepareFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.PrepareFlowsRequest`
@@ -296,7 +423,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PrepareFlows", params)
+            headers = request.headers
+            body = self.call("PrepareFlows", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PrepareFlowsResponse()
@@ -324,7 +452,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SyncProxyOrganization", params)
+            headers = request.headers
+            body = self.call("SyncProxyOrganization", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SyncProxyOrganizationResponse()
@@ -352,7 +481,8 @@ class EssbasicClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SyncProxyOrganizationOperators", params)
+            headers = request.headers
+            body = self.call("SyncProxyOrganizationOperators", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SyncProxyOrganizationOperatorsResponse()
@@ -363,6 +493,36 @@ class EssbasicClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UploadFiles(self, request):
+        """此接口（UploadFiles）用于文件上传。
+        调用时需要设置Domain 为 file.ess.tencent.cn
+
+        :param request: Request instance for UploadFiles.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.UploadFilesRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.UploadFilesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UploadFiles", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UploadFilesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
